#region File Description
//-----------------------------------------------------------------------------
// CpuSkinnedModelReader.cs
//
// Microsoft XNA Community Game Platform
// Copyright (C) Microsoft Corporation. All rights reserved.
//-----------------------------------------------------------------------------
#endregion

using System.Collections.Generic;
using System.Collections.ObjectModel;
using Microsoft.Xna.Framework.Content;
using Microsoft.Xna.Framework.Graphics;

namespace CpuSkinningDataTypes
{
    /// <summary>
    /// A custom reader to read our CpuSkinnedModel from an XNB.
    /// </summary>
    public class CpuSkinnedModelReader : ContentTypeReader<CpuSkinnedModel>
    {
        protected override CpuSkinnedModel Read(ContentReader input, CpuSkinnedModel existingInstance)
        {
            CpuSkinnedModel cpuSkinnedModel;
            
            if(existingInstance==null)
            {
            // read in the model parts
                List<CpuSkinnedModelPart> modelParts;
                modelParts = ReadModelParts(input, null);
            // read in the skinning data
            SkinningData skinningData = input.ReadObject<SkinningData>();
                cpuSkinnedModel = new CpuSkinnedModel(modelParts, skinningData);
            }
            else
            {
                cpuSkinnedModel = existingInstance;
                ReadModelParts(input, cpuSkinnedModel.modelParts);
                input.ReadObject<SkinningData>(cpuSkinnedModel.SkinningData);
            }

            return cpuSkinnedModel;
        }

        /// <remarks>We don't excpect to to gain much boost by inlining CpuSkinnedModelPart.
        /// This is done just to workaround some bugs in the current MG Content readers during ReloadAssets
        /// </remarks>
        private List<CpuSkinnedModelPart> ReadModelParts(ContentReader input, List<CpuSkinnedModelPart> existingInstance)
        {
            List<CpuSkinnedModelPart> modelParts = existingInstance;

            int count = input.ReadInt32();
            if (modelParts == null) 
                modelParts = new List<CpuSkinnedModelPart>(count);

            for (int i = 0; i < count; i++)
            {
                if (existingInstance == null)
                    modelParts.Add(ReadModelPart(input, null));
                else
                    ReadModelPart(input, modelParts[i]);
        }
            
            return modelParts;
    }

        private CpuSkinnedModelPart ReadModelPart(ContentReader input, CpuSkinnedModelPart existingInstance)
        {
            CpuSkinnedModelPart modelPart = existingInstance;

            // read in all of our data
            int triangleCount = input.ReadInt32();

            if (existingInstance == null)
            {
            CpuVertex[] cpuVertices = input.ReadObject<CpuVertex[]>();
            IndexBuffer indexBuffer = input.ReadObject<IndexBuffer>();
                modelPart = new CpuSkinnedModelPart(triangleCount, cpuVertices, indexBuffer);
            }
            else
            {
                input.ReadObject<CpuVertex[]>(modelPart.cpuVertices);
                input.ReadObject<IndexBuffer>(modelPart.IndexBuffer);
            }

            // read in the BasicEffect as a shared resource
            input.ReadSharedResource<BasicEffect>(fx => modelPart.Effect = fx);

            return modelPart;
        }
    }
    
}
