#region File Description
//-----------------------------------------------------------------------------
// CpuSkinnedModelWriter.cs
//
// Microsoft XNA Community Game Platform
// Copyright (C) Microsoft Corporation. All rights reserved.
//-----------------------------------------------------------------------------
#endregion

using Microsoft.Xna.Framework.Content.Pipeline;
using Microsoft.Xna.Framework.Content.Pipeline.Serialization.Compiler;
using System.Collections.Generic;
using System;
using CpuSkinningDataTypes;

namespace CpuSkinningPipelineExtensions
{
    /// <summary>
    /// Writes out a CpuSkinnedModelContent object to an XNB file to be read in as
    /// a CpuSkinnedModel.
    /// </summary>
    [ContentTypeWriter]
    class CpuSkinnedModelWriter : ContentTypeWriter<CpuSkinnedModelContent>
    {
        protected override void Write(ContentWriter output, CpuSkinnedModelContent value)
        {
            WriteModelParts(output, value.ModelParts);
            output.WriteObject(value.SkinningData);
        }

        private void WriteModelParts(ContentWriter output, List<CpuSkinnedModelPartContent> modelParts)
        {            
            Int32 count = modelParts.Count;
            output.Write((Int32)count);

            for (int i = 0; i < count; i++)
            {
                CpuSkinnedModelPartContent modelPart = modelParts[i];
                WriteModelPart(output, modelPart);
            }

            return;
		}

        private void WriteModelPart(ContentWriter output, CpuSkinnedModelPartContent modelPart)
        {
            output.Write(modelPart.TriangleCount);
            output.WriteObject(modelPart.Vertices);
            output.WriteObject(modelPart.IndexCollection);
            output.WriteSharedResource(modelPart.Material);
		}

        public override string GetRuntimeType(TargetPlatform targetPlatform)
        {
            return "CpuSkinningDataTypes.CpuSkinnedModel, CpuSkinningDataTypes";
        }

        public override string GetRuntimeReader(TargetPlatform targetPlatform)
        {
            return "CpuSkinningDataTypes.CpuSkinnedModelReader, CpuSkinningDataTypes";
        }
    }

}
